/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.util.Date;

/**
 * 预入职-员工伤残信息表
 *
 * @author hgw
 * @date 2024-06-17 11:24:01
 */
@Data
@TableName("t_pre_emp_disability_info")
@EqualsAndHashCode(callSuper = true)
@Schema(description = "预入职-员工伤残信息表")
public class TPreEmpDisabilityInfo extends BaseEntity {

	/**
	 * 主键
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@ExcelProperty("主键")
	@Schema(description = "主键")
	private String id;
	/**
	 * 预入职主表ID
	 */
	@ExcelAttribute(name = "预入职主表ID", isNotEmpty = true, errorInfo = "预入职主表ID不能为空", maxLength = 32)
	@NotBlank(message = "预入职主表ID不能为空")
	@Length(max = 32, message = "预入职主表ID不能超过32个字符")
	@ExcelProperty("预入职主表ID")
	@Schema(description = "预入职主表ID")
	private String preMainId;
	/**
	 * 员工ID
	 */
	@ExcelAttribute(name = "员工ID", isNotEmpty = true, errorInfo = "员工ID不能为空", maxLength = 32)
	@NotBlank(message = "员工ID不能为空")
	@Length(max = 32, message = "员工ID不能超过32个字符")
	@ExcelProperty("员工ID")
	@Schema(description = "员工ID")
	private String empId;
	/**
	 * 员工姓名
	 */
	@ExcelAttribute(name = "员工姓名", isNotEmpty = true, errorInfo = "员工姓名不能为空", maxLength = 50)
	@NotBlank(message = "员工姓名不能为空")
	@Length(max = 50, message = "员工姓名不能超过50个字符")
	@ExcelProperty("员工姓名")
	@Schema(description = "员工姓名")
	private String empName;
	/**
	 * 员工编码
	 */
	@ExcelAttribute(name = "员工编码", isNotEmpty = true, errorInfo = "员工编码不能为空", maxLength = 50)
	@NotBlank(message = "员工编码不能为空")
	@Length(max = 50, message = "员工编码不能超过50个字符")
	@ExcelProperty("员工编码")
	@Schema(description = "员工编码")
	private String empCode;
	/**
	 * 身份证号
	 */
	@ExcelAttribute(name = "身份证号", isNotEmpty = true, errorInfo = "身份证号不能为空", maxLength = 32)
	@NotBlank(message = "身份证号不能为空")
	@Length(max = 32, message = "身份证号不能超过32个字符")
	@ExcelProperty("身份证号")
	@Schema(description = "身份证号")
	private String empIdcard;
	/**
	 * 伤残病名称
	 */
	@ExcelAttribute(name = "伤残病名称", isNotEmpty = true, errorInfo = "伤残病名称不能为空", maxLength = 50)
	@NotBlank(message = "伤残病名称不能为空")
	@Length(max = 50, message = "伤残病名称不能超过50个字符")
	@ExcelProperty("伤残病名称")
	@Schema(description = "伤残病名称")
	private String disabilityName;
	/**
	 * 伤残等级
	 */
	@ExcelAttribute(name = "伤残等级", maxLength = 32)
	@Length(max = 32, message = "伤残等级不能超过32个字符")
	@ExcelProperty("伤残等级")
	@Schema(description = "伤残等级")
	private String disabilityLevel;
	/**
	 * 是否工伤标识0是/1否
	 */
	@ExcelAttribute(name = "是否工伤标识0是/1否", maxLength = 1)
	@Length(max = 1, message = "是否工伤标识0是/1否不能超过1个字符")
	@ExcelProperty("是否工伤标识0是/1否")
	@Schema(description = "是否工伤标识0是/1否")
	private String injuryIdentification;
	/**
	 * 伤残开始日期
	 */
	@ExcelAttribute(name = "伤残开始日期", isDate = true)
	@ExcelProperty("伤残开始日期")
	@Schema(description = "伤残开始日期")
	private Date startTime;
	/**
	 * 伤残结束日期
	 */
	@ExcelAttribute(name = "伤残结束日期", isDate = true)
	@ExcelProperty("伤残结束日期")
	@Schema(description = "伤残结束日期")
	private Date endTime;
	/**
	 * 职业病名称
	 */
	@ExcelAttribute(name = "职业病名称", maxLength = 50)
	@Length(max = 50, message = "职业病名称不能超过50个字符")
	@ExcelProperty("职业病名称")
	@Schema(description = "职业病名称")
	private String occupationalDisease;
	/**
	 * 0删除作废1正常
	 */
	@ExcelAttribute(name = "0删除作废1正常", maxLength = 1)
	@Length(max = 1, message = "0删除作废1正常不能超过1个字符")
	@ExcelProperty("0删除作废1正常")
	@Schema(description = "0删除作废1正常")
	private String deleteFlag;
	/**
	 * 结算主体ID
	 */
	@ExcelAttribute(name = "结算主体ID", maxLength = 32)
	@Length(max = 32, message = "结算主体ID不能超过32个字符")
	@ExcelProperty("结算主体ID")
	@Schema(description = "结算主体ID")
	private String settleDomain;
	/**
	 * 备注
	 */
	@ExcelAttribute(name = "备注", maxLength = 200)
	@Length(max = 200, message = "备注不能超过200个字符")
	@ExcelProperty("备注")
	@Schema(description = "备注")
	private String remark;

}
