/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.archives.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.RowIndex;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.util.Date;

/**
 * 预入职-主表
 *
 * @author hgw
 * @date 2024-06-17 11:31:08
 */
@Data
public class TPreEmpMainVo extends RowIndex implements Serializable {

	/**
	 * 主键
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@NotBlank(message = "主键 不能为空")
	@Length(max = 32, message = "主键 不能超过32 个字符")
	@ExcelAttribute(name = "主键", isNotEmpty = true, errorInfo = "主键 不能为空", maxLength = 32)
	@Schema(description = "主键")
	@ExcelProperty("主键")
	private String id;
	/**
	 * 审核状态（0待完善；1待审核；2审核通过；3审核不通过）
	 */
	@NotBlank(message = "审核状态（0待完善；1待审核；2审核通过；3审核不通过） 不能为空")
	@Length(max = 1, message = "审核状态（0待完善；1待审核；2审核通过；3审核不通过） 不能超过1 个字符")
	@ExcelAttribute(name = "审核状态（0待完善；1待审核；2审核通过；3审核不通过）", isNotEmpty = true, errorInfo = "审核状态（0待完善；1待审核；2审核通过；3审核不通过） 不能为空", maxLength = 1)
	@Schema(description = "审核状态（0待完善；1待审核；2审核通过；3审核不通过）")
	@ExcelProperty("审核状态（0待完善；1待审核；2审核通过；3审核不通过）")
	private String status;
	/**
	 * 员工ID
	 */
	@Length(max = 32, message = "员工ID 不能超过32 个字符")
	@ExcelAttribute(name = "员工ID", maxLength = 32)
	@Schema(description = "员工ID")
	@ExcelProperty("员工ID")
	private String empId;
	/**
	 * 员工姓名
	 */
	@Length(max = 32, message = "员工姓名 不能超过32 个字符")
	@ExcelAttribute(name = "员工姓名", maxLength = 32)
	@Schema(description = "员工姓名")
	@ExcelProperty("员工姓名")
	private String empName;
	/**
	 * 身份证号
	 */
	@Length(max = 20, message = "身份证号 不能超过20 个字符")
	@ExcelAttribute(name = "身份证号", maxLength = 20)
	@Schema(description = "身份证号")
	@ExcelProperty("身份证号")
	private String empIdcard;
	/**
	 * 手机号码
	 */
	@Length(max = 32, message = "手机号码 不能超过32 个字符")
	@ExcelAttribute(name = "手机号码", maxLength = 32)
	@Schema(description = "手机号码")
	@ExcelProperty("手机号码")
	private String empPhone;
	/**
	 * 微信名
	 */
	@Length(max = 32, message = "微信名 不能超过32 个字符")
	@ExcelAttribute(name = "微信名", maxLength = 32)
	@Schema(description = "微信名")
	@ExcelProperty("微信名")
	private String empWx;
	/**
	 * 客户id
	 */
	@Length(max = 32, message = "客户id 不能超过32 个字符")
	@ExcelAttribute(name = "客户id", maxLength = 32)
	@Schema(description = "客户id")
	@ExcelProperty("客户id")
	private String unitId;
	/**
	 * 客户名称
	 */
	@Length(max = 50, message = "客户名称 不能超过50 个字符")
	@ExcelAttribute(name = "客户名称", maxLength = 50)
	@Schema(description = "客户名称")
	@ExcelProperty("客户名称")
	private String unitName;
	/**
	 * 客户编码
	 */
	@Length(max = 32, message = "客户编码 不能超过32 个字符")
	@ExcelAttribute(name = "客户编码", maxLength = 32)
	@Schema(description = "客户编码")
	@ExcelProperty("客户编码")
	private String unitNo;
	/**
	 * 项目id
	 */
	@Length(max = 32, message = "项目id 不能超过32 个字符")
	@ExcelAttribute(name = "项目id", maxLength = 32)
	@Schema(description = "项目id")
	@ExcelProperty("项目id")
	private String deptId;
	/**
	 * 项目名称
	 */
	@Length(max = 50, message = "项目名称 不能超过50 个字符")
	@ExcelAttribute(name = "项目名称", maxLength = 50)
	@Schema(description = "项目名称")
	@ExcelProperty("项目名称")
	private String deptName;
	/**
	 * 项目编码
	 */
	@NotBlank(message = "项目编码 不能为空")
	@Length(max = 30, message = "项目编码 不能超过30 个字符")
	@ExcelAttribute(name = "项目编码", isNotEmpty = true, errorInfo = "项目编码 不能为空", maxLength = 30)
	@Schema(description = "项目编码")
	@ExcelProperty("项目编码")
	private String deptNo;
	/**
	 * 业务类型一级分类
	 */
	@Length(max = 32, message = "业务类型一级分类 不能超过32 个字符")
	@ExcelAttribute(name = "业务类型一级分类", maxLength = 32)
	@Schema(description = "业务类型一级分类")
	@ExcelProperty("业务类型一级分类")
	private String businessPrimaryType;
	/**
	 * 业务类型二级分类
	 */
	@Length(max = 32, message = "业务类型二级分类 不能超过32 个字符")
	@ExcelAttribute(name = "业务类型二级分类", maxLength = 32)
	@Schema(description = "业务类型二级分类")
	@ExcelProperty("业务类型二级分类")
	private String businessSecondType;
	/**
	 * 业务类型三级分类
	 */
	@Length(max = 32, message = "业务类型三级分类 不能超过32 个字符")
	@ExcelAttribute(name = "业务类型三级分类", maxLength = 32)
	@Schema(description = "业务类型三级分类")
	@ExcelProperty("业务类型三级分类")
	private String businessThirdType;
	/**
	 * 员工类型（字典值，0外包1派遣2代理）
	 */
	@NotBlank(message = "员工类型（字典值，0外包1派遣2代理） 不能为空")
	@Length(max = 2, message = "员工类型（字典值，0外包1派遣2代理） 不能超过2 个字符")
	@ExcelAttribute(name = "员工类型（字典值，0外包1派遣2代理）", isNotEmpty = true, errorInfo = "员工类型（字典值，0外包1派遣2代理） 不能为空", maxLength = 2)
	@Schema(description = "员工类型（字典值，0外包1派遣2代理）")
	@ExcelProperty("员工类型（字典值，0外包1派遣2代理）")
	private String empNatrue;
	/**
	 * 审核人ID
	 */
	@Length(max = 32, message = "审核人ID 不能超过32 个字符")
	@ExcelAttribute(name = "审核人ID", maxLength = 32)
	@Schema(description = "审核人ID")
	@ExcelProperty("审核人ID")
	private String auditId;
	/**
	 * 审核人姓名
	 */
	@Length(max = 20, message = "审核人姓名 不能超过20 个字符")
	@ExcelAttribute(name = "审核人姓名", maxLength = 20)
	@Schema(description = "审核人姓名")
	@ExcelProperty("审核人姓名")
	private String auditName;
	/**
	 * 审核时间
	 */
	@ExcelAttribute(name = "审核时间", isDate = true)
	@Schema(description = "审核时间")
	@ExcelProperty("审核时间")
	private Date auditTime;
	/**
	 * 创建者
	 */
	@Length(max = 64, message = "创建者 不能超过64 个字符")
	@ExcelAttribute(name = "创建者", maxLength = 64)
	@Schema(description = "创建者")
	@ExcelProperty("创建者")
	private String createBy;
	/**
	 * 更新人
	 */
	@Length(max = 64, message = "更新人 不能超过64 个字符")
	@ExcelAttribute(name = "更新人", maxLength = 64)
	@Schema(description = "更新人")
	@ExcelProperty("更新人")
	private String updateBy;
	/**
	 * 创建人姓名
	 */
	@Length(max = 32, message = "创建人姓名 不能超过32 个字符")
	@ExcelAttribute(name = "创建人姓名", maxLength = 32)
	@Schema(description = "创建人姓名")
	@ExcelProperty("创建人姓名")
	private String createName;
	/**
	 * 创建时间
	 */
	@ExcelAttribute(name = "创建时间", isDate = true)
	@Schema(description = "创建时间")
	@ExcelProperty("创建时间")
	private Date createTime;
	/**
	 * 更新时间
	 */
	@ExcelAttribute(name = "更新时间", isDate = true)
	@Schema(description = "更新时间")
	@ExcelProperty("更新时间")
	private Date updateTime;
	/**
	 * 结算主体ID
	 */
	@Length(max = 32, message = "结算主体ID 不能超过32 个字符")
	@ExcelAttribute(name = "结算主体ID", maxLength = 32)
	@Schema(description = "结算主体ID")
	@ExcelProperty("结算主体ID")
	private String settleDomain;

}
